@@ -38,7 +38,10 @@ use crate::{
     renderer::{RendererSettings, Rendering, WindowRenderer},
 };
 use log::{debug, error, info, trace};
-use std::time::{Duration, Instant};
+use std::{
+    thread,
+    time::{Duration, Instant},
+};
 
 /// Builds a [`PixEngine`] instance by providing several configration functions.
 ///
@@ -157,6 +160,12 @@ impl Builder {
         self
     }
 
+    /// Set number of audio channels.
+    pub fn audio_channels(&mut self, channels: u8) -> &mut Self {
+        self.settings.audio_channels = channels;
+        self
+    }
+
     /// Start window in fullscreen mode.
     pub fn fullscreen(&mut self) -> &mut Self {
         self.settings.fullscreen = true;
@@ -335,6 +344,12 @@ impl PixEngine {
                         self.state.increment_frame(now, time_since_last)?;
                     }
                 }
+
+                let time_to_next_frame = now + target_delta_time;
+                let now = Instant::now();
+                if time_to_next_frame > now {
+                    thread::sleep(time_to_next_frame - now);
+                }
             };
 
             debug!("Quitting with `AppState::on_stop`");
@@ -359,7 +374,10 @@ impl PixEngine {
             // Demote noisy events to trace
             if let Event::ControllerAxisMotion { .. }
             | Event::JoyAxisMotion { .. }
-            | Event::MouseMotion { .. } = event
+            | Event::MouseMotion { .. }
+            | Event::MouseWheel { .. }
+            | Event::KeyDown { repeat: true, .. }
+            | Event::KeyUp { repeat: true, .. } = event
             {
                 trace!("Polling event {:?}", event);
             } else {
