@@ -205,7 +205,7 @@ impl Rendering for Renderer {
         let audio_device = audio_sub
             .open_queue(None, &desired_spec)
             .map_err(PixError::Renderer)?;
-        audio_device.resume();
+        debug!("Loaded AudioDevice: {:?}", audio_device.spec());
         let controller_subsys = context.game_controller().map_err(PixError::Renderer)?;
 
         let default_font = Font::default();
@@ -343,7 +343,7 @@ impl Rendering for Renderer {
                 .ok_or(PixError::InvalidWindow(self.window_target))?;
             let texture = WindowCanvas::text_texture_mut(
                 &mut window.text_cache,
-                &window.texture_creator,
+                &window.canvas,
                 text,
                 wrap_width,
                 fill,
@@ -690,7 +690,7 @@ impl Rendering for Renderer {
             .get_mut(&self.window_target)
             .ok_or(PixError::InvalidWindow(self.window_target))?;
         let texture =
-            WindowCanvas::image_texture_mut(&mut window.image_cache, &window.texture_creator, img)?;
+            WindowCanvas::image_texture_mut(&mut window.image_cache, &window.canvas, img)?;
         let [r, g, b, a] = tint.map_or([255; 4], |t| t.channels());
         texture.set_color_mod(r, g, b);
         texture.set_alpha_mod(a);
